@@ -9,7 +9,7 @@ use Exception::Delayed;
 use Carp qw(croak confess);
 use HTTP::Headers::Fancy 1.001 ();
 
-our $VERSION = '0.001';    # VERSION
+our $VERSION = '0.002';    # VERSION
 
 use namespace::clean;
 
@@ -73,7 +73,12 @@ sub _header {
     my $str = '#' x ( $level + $Offset );
     $str .= " $title\n\n";
     $body = _indent( $body, $indent ) if $indent;
-    $str .= "$body\n\n" if $body;
+    if ( ref $body eq 'ARRAY' ) {
+        $str .= Concat(@$body) . "\n\n";
+    }
+    elsif ($body) {
+        $str .= "$body\n\n";
+    }
     return $str;
 }
 
@@ -112,15 +117,19 @@ use namespace::clean;
 
 our @EXPORT_OK;
 
-# Compile: Meta Intro Resource Group Concat
+# Compile (8) Meta Intro Resource Group Concat
 BEGIN { push @EXPORT_OK => qw(Compile) }
 
 sub Compile {
     my $struct = shift;
     my @Body;
-    push @Body => Meta( delete $struct->{host} );
-    push @Body =>
-      Intro( delete $struct->{name}, delete $struct->{description} );
+
+    my ( $host, $name, $description ) =
+      map { delete $struct->{$_} } qw(host name description);
+
+    push @Body => Meta($host);
+    push @Body => Intro( $name, $description ) if $name;
+
     if ( my $resources = delete $struct->{resources} ) {
         foreach my $resource (@$resources) {
             push @Body => Resource($resource);
@@ -136,10 +145,10 @@ sub Compile {
         );
     }
     _complain( Compile => $struct );
-    return _autoprint( wantarray, Concat(@Body) );
+    return _autoprint( wantarray, Concat(@Body) . "\n" );
 }
 
-# Section:
+# Section (-)
 BEGIN { push @EXPORT_OK => qw(Section) }
 
 sub Section {
@@ -156,7 +165,7 @@ sub Section {
     return _autoprint( wantarray, $str );
 }
 
-# Meta:
+# Meta (0)
 BEGIN { push @EXPORT_OK => qw(Meta) }
 
 sub Meta {
@@ -167,6 +176,7 @@ sub Meta {
     return _autoprint( wantarray, "$str\n" );
 }
 
+# Intro (0)
 BEGIN { push @EXPORT_OK => qw(Intro) }
 
 sub Intro {
@@ -174,7 +184,7 @@ sub Intro {
     return _autoprint( wantarray, _header( 1, $name, $description // '' ) );
 }
 
-# Concat:
+# Concat (0)
 BEGIN { push @EXPORT_OK => qw(Concat) }
 
 sub Concat {
@@ -182,7 +192,7 @@ sub Concat {
         @_ );
 }
 
-# Text: Concat
+# Text (1) Concat
 BEGIN { push @EXPORT_OK => qw(Text) }
 
 sub Text {
@@ -190,7 +200,7 @@ sub Text {
         Concat( map { _flatten($_) } map { s{[\r\n]+}{\n}gr } @_ ) );
 }
 
-# Code:
+# Code (0)
 BEGIN { push @EXPORT_OK => qw(Code) }
 
 sub Code {
@@ -206,7 +216,7 @@ sub Code {
     return _autoprint( wantarray, "$delimiter$lang\n$code\n$delimiter\n\n" );
 }
 
-# Group: Concat Resource
+# Group (2) Concat Resource
 BEGIN { push @EXPORT_OK => qw(Group) }
 
 sub Group {
@@ -218,7 +228,7 @@ sub Group {
         _header( 1, "Group $identifier", $body, $indent ) );
 }
 
-# Resource: Sesction Parameters Model Attributes Action
+# Resource (7) Sesction Parameters Model Attributes Action
 BEGIN { push @EXPORT_OK => qw(Resource) }
 
 sub Resource {
@@ -239,7 +249,12 @@ sub Resource {
     }
     else {
         my @body;
-        push @body => $description            if defined $description;
+        if ( ref $description eq 'ARRAY' ) {
+            push @body => @$description;
+        }
+        elsif ( defined $description ) {
+            push @body => $description;
+        }
         push @body => Parameters($parameters) if defined $parameters;
         push @body => Attributes($attributes) if defined $attributes;
         push @body => Model($model)           if defined $model;
@@ -263,7 +278,7 @@ sub Resource {
     }
 }
 
-# Model: Payload
+# Model (4) Payload
 BEGIN { push @EXPORT_OK => qw(Model) }
 
 sub Model {
@@ -280,7 +295,7 @@ sub Model {
     }
 }
 
-# Schema:
+# Schema (0)
 BEGIN { push @EXPORT_OK => qw(Schema) }
 
 sub Schema {
@@ -288,6 +303,7 @@ sub Schema {
     return _autoprint( wantarray, _listitem( "Schema", $body, $indent ) );
 }
 
+# Attribute (-)
 sub Attribute;
 BEGIN { push @EXPORT_OK => qw(Attribute) }
 
@@ -327,7 +343,7 @@ sub Attribute {
     return $str;
 }
 
-# Attributes:
+# Attributes (0) Attribute
 BEGIN { push @EXPORT_OK => qw(Attributes) }
 
 sub Attributes {
@@ -348,7 +364,7 @@ sub Attributes {
     }
 }
 
-# Action: Section Relation Parameters Attributes Asset Reference Request_Ref Request Response_Ref Response Concat
+# Action (6) Section Relation Parameters Attributes Asset Reference Request_Ref Request Response_Ref Response Concat
 BEGIN { push @EXPORT_OK => qw(Action) }
 
 sub Action {
@@ -369,7 +385,12 @@ sub Action {
     }
     else {
         my @body;
-        push @body => $description            if defined $description;
+        if ( ref $description eq 'ARRAY' ) {
+            push @body => @$description;
+        }
+        elsif ( defined $description ) {
+            push @body => $description;
+        }
         push @body => Relation($relation)     if defined $relation;
         push @body => Parameters($parameters) if defined $parameters;
         push @body => Attributes($attributes) if defined $attributes;
@@ -435,13 +456,20 @@ sub Action {
     }
 }
 
-# Payload: Headers Attributes Body Body_CODE Body_YAML Body_JSON Schema Concat
+# Payload (3) Headers Attributes Body Body_CODE Body_YAML Body_JSON Schema Concat
 BEGIN { push @EXPORT_OK => qw(Payload) }
 
 sub Payload {
     my $args = shift;
     my @body;
-    push @body => delete $args->{description} if exists $args->{description};
+    if ( exists $args->{description} ) {
+        if ( ref $args->{description} eq 'ARRAY' ) {
+            push @body => @{ delete $args->{description} };
+        }
+        else {
+            push @body => delete $args->{description};
+        }
+    }
     push @body => Headers( delete $args->{headers} ) if exists $args->{headers};
     push @body => Attributes( delete $args->{attributes} )
       if exists $args->{attributes};
@@ -465,7 +493,7 @@ sub Payload {
     return _autoprint( wantarray, Concat(@body) );
 }
 
-# Asset: Payload
+# Asset (4) Payload
 BEGIN { push @EXPORT_OK => qw(Asset) }
 
 sub Asset {
@@ -477,7 +505,7 @@ sub Asset {
     return _autoprint( wantarray, _listitem( $str, Payload($payload) ) );
 }
 
-# Reference:
+# Reference (0)
 BEGIN { push @EXPORT_OK => qw(Reference) }
 
 sub Reference {
@@ -486,7 +514,7 @@ sub Reference {
         _listitem( "$keyword $identifier", "[$reference][]" ) );
 }
 
-# Request: Asset
+# Request (5) Asset
 BEGIN { push @EXPORT_OK => qw(Request) }
 
 sub Request {
@@ -494,7 +522,7 @@ sub Request {
     goto &Asset;
 }
 
-# Request_Ref: Reference
+# Request_Ref (1) Reference
 BEGIN { push @EXPORT_OK => qw(Request_Ref) }
 
 sub Request_Ref {
@@ -502,7 +530,7 @@ sub Request_Ref {
     goto &Reference;
 }
 
-# Response: Asset
+# Response (5) Asset
 BEGIN { push @EXPORT_OK => qw(Response) }
 
 sub Response {
@@ -510,7 +538,7 @@ sub Response {
     goto &Asset;
 }
 
-# Response_Ref: Reference
+# Response_Ref (1) Reference
 BEGIN { push @EXPORT_OK => qw(Response_Ref) }
 
 sub Response_Ref {
@@ -518,7 +546,7 @@ sub Response_Ref {
     goto &Reference;
 }
 
-# Parameters: Parameter
+# Parameters (2) Parameter
 BEGIN { push @EXPORT_OK => qw(Parameters) }
 
 sub Parameters {
@@ -533,7 +561,7 @@ sub Parameters {
     return _autoprint( wantarray, _listitem( 'Parameters', $body ) );
 }
 
-# Parameter: Concat
+# Parameter (1) Concat
 BEGIN { push @EXPORT_OK => qw(Parameter) }
 
 sub Parameter {
@@ -580,7 +608,7 @@ sub Parameter {
     return _autoprint( wantarray, _listitem( $str, $itembody ) );
 }
 
-# Headers:
+# Headers (0)
 BEGIN { push @EXPORT_OK => qw(Headers) }
 
 sub Headers {
@@ -598,7 +626,7 @@ sub Headers {
     return _autoprint( wantarray, _listitem( 'Headers', $body ) );
 }
 
-# Body:
+# Body (0)
 BEGIN { push @EXPORT_OK => qw(Body) }
 
 sub Body {
@@ -606,7 +634,7 @@ sub Body {
     return _autoprint( wantarray, _listitem( 'Body', $body, 8 ) );
 }
 
-# Body_CODE: Code
+# Body_CODE (1) Code
 BEGIN { push @EXPORT_OK => qw(Body_CODE) }
 
 sub Body_CODE {
@@ -619,7 +647,7 @@ sub _yaml {
     YAML::Any::Dump($struct);
 }
 
-# Body_YAML: Body_CODE
+# Body_YAML (2) Body_CODE
 BEGIN { push @EXPORT_OK => qw(Body_YAML) }
 
 sub Body_YAML {
@@ -634,7 +662,7 @@ sub _json {
     $JSON->encode($struct);
 }
 
-# Body_JSON: Body_CODE
+# Body_JSON (2) Body_CODE
 BEGIN { push @EXPORT_OK => qw(Body_JSON) }
 
 sub Body_JSON {
@@ -642,7 +670,7 @@ sub Body_JSON {
     return _autoprint( wantarray, Body_CODE( _json($struct), 'json' ) );
 }
 
-# Relation:
+# Relation (0)
 BEGIN { push @EXPORT_OK => qw(Relation) }
 
 sub Relation {
@@ -662,7 +690,7 @@ Text::API::Blueprint - Markdown generator for API blueprint format
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 FUNCTIONS
 
